@@ -1,6 +1,6 @@
 // This file is part of https://github.com/SpringQL/SpringQL which is licensed under MIT OR Apache-2.0. See file LICENSE-MIT or LICENSE-APACHE for full license details.
 
-use crate::stream_engine::time::duration::event_duration::EventDuration;
+use crate::stream_engine::time::duration::event_duration::SpringEventDuration;
 
 /// Window parameters
 #[derive(Clone, Eq, PartialEq, Debug)]
@@ -18,9 +18,9 @@ pub(crate) enum WindowParameter {
     ///      :00  :05  :10  :15  :20
     /// ```
     TimedSlidingWindow {
-        length: EventDuration,
-        period: EventDuration,
-        allowed_delay: EventDuration,
+        length: SpringEventDuration,
+        period: SpringEventDuration,
+        allowed_delay: SpringEventDuration,
     },
 
     /// Time-based fixed window
@@ -36,27 +36,27 @@ pub(crate) enum WindowParameter {
     ///      :00  :05  :10  :15  :20
     /// ```
     TimedFixedWindow {
-        length: EventDuration,
-        allowed_delay: EventDuration,
+        length: SpringEventDuration,
+        allowed_delay: SpringEventDuration,
     },
 }
 
 impl WindowParameter {
-    pub(crate) fn length(&self) -> EventDuration {
+    pub(crate) fn length(&self) -> SpringEventDuration {
         match self {
             WindowParameter::TimedSlidingWindow { length, .. } => *length,
             WindowParameter::TimedFixedWindow { length, .. } => *length,
         }
     }
 
-    pub(crate) fn period(&self) -> EventDuration {
+    pub(crate) fn period(&self) -> SpringEventDuration {
         match self {
             WindowParameter::TimedSlidingWindow { period, .. } => *period,
             WindowParameter::TimedFixedWindow { length, .. } => *length,
         }
     }
 
-    pub(crate) fn allowed_delay(&self) -> EventDuration {
+    pub(crate) fn allowed_delay(&self) -> SpringEventDuration {
         match self {
             WindowParameter::TimedSlidingWindow { allowed_delay, .. } => *allowed_delay,
             WindowParameter::TimedFixedWindow { allowed_delay, .. } => *allowed_delay,
