@@ -21,9 +21,10 @@ use self::memory_state_machine_worker_thread::{
 };
 
 use super::{
-    event_queue::EventQueue,
+    args::{Coordinators, EventQueues},
+    main_job_lock::MainJobLock,
     memory_state_machine::MemoryStateMachineThreshold,
-    worker::worker_handle::{WorkerHandle, WorkerStopCoordinate},
+    worker::worker_handle::WorkerHandle,
 };
 
 #[derive(Debug)]
@@ -34,14 +35,16 @@ pub(in crate::stream_engine::autonomous_executor) struct MemoryStateMachineWorke
 impl MemoryStateMachineWorker {
     pub(in crate::stream_engine::autonomous_executor) fn new(
         memory_config: &SpringMemoryConfig,
-        event_queue: Arc<EventQueue>,
-        worker_stop_coordinate: Arc<WorkerStopCoordinate>,
+        main_job_lock: Arc<MainJobLock>,
+        event_queues: EventQueues,
+        coordinators: Coordinators,
     ) -> Self {
         let threshold = MemoryStateMachineThreshold::from(memory_config);
 
         let handle = WorkerHandle::new::<MemoryStateMachineWorkerThread>(
-            event_queue,
-            worker_stop_coordinate,
+            main_job_lock,
+            event_queues,
+            coordinators,
             MemoryStateMachineWorkerThreadArg::new(
                 threshold,
                 memory_config.memory_state_transition_interval_msec,
