@@ -4,22 +4,24 @@ use crate::{
     error::Result,
     stream_engine::{
         autonomous_executor::row::value::sql_value::nn_sql_value::NnSqlValue,
-        time::timestamp::Timestamp,
+        time::timestamp::SpringTimestamp,
     },
 };
 
-use super::SqlConvertible;
-
-impl SqlConvertible for Timestamp {
-    fn into_sql_value(self) -> NnSqlValue {
-        NnSqlValue::Timestamp(self)
-    }
+use super::{SpringValue, ToNnSqlValue};
 
+impl SpringValue for SpringTimestamp {
     fn try_from_string(s: &str) -> Result<Self> {
         s.parse()
     }
 
-    fn try_from_timestamp(v: &Timestamp) -> Result<Self> {
+    fn try_from_timestamp(v: &SpringTimestamp) -> Result<Self> {
         Ok(*v)
     }
 }
+
+impl ToNnSqlValue for SpringTimestamp {
+    fn into_sql_value(self) -> NnSqlValue {
+        NnSqlValue::Timestamp(self)
+    }
+}
