@@ -62,7 +62,7 @@ impl SinkWriter for NetSinkWriter {
         let mut json_s = JsonObject::from(row).to_string();
         json_s.push('\n');
 
-        log::info!("[NetSinkWriter] Writing message to remote: {}", json_s);
+        log::debug!("[NetSinkWriter] Writing message to remote: {}", json_s);
 
         self.tcp_stream_writer
             .write_all(json_s.as_bytes())
