@@ -5,16 +5,13 @@ pub(super) mod generic_worker;
 use std::{cell::RefCell, sync::Arc};
 
 use crate::stream_engine::autonomous_executor::{
-    event_queue::EventQueue, repositories::Repositories,
-    worker::worker_handle::WorkerStopCoordinate,
+    args::{Coordinators, EventQueues, Locks},
+    repositories::Repositories,
 };
 
 use self::generic_worker::GenericWorker;
 
-use super::{
-    task_executor_lock::TaskExecutorLock,
-    task_worker_thread_handler::{TaskWorkerId, TaskWorkerThreadArg},
-};
+use super::task_worker_thread_handler::{TaskWorkerId, TaskWorkerThreadArg};
 
 /// Workers to execute pump and sink tasks.
 #[derive(Debug)]
@@ -30,19 +27,24 @@ pub(super) struct GenericWorkerPool {
 impl GenericWorkerPool {
     pub(super) fn new(
         n_worker_threads: u16,
-        event_queue: Arc<EventQueue>,
-        worker_stop_coordinate: Arc<WorkerStopCoordinate>,
-        task_executor_lock: Arc<TaskExecutorLock>,
+        locks: Locks,
+        event_queues: EventQueues,
+        coordinators: Coordinators,
         repos: Arc<Repositories>,
     ) -> Self {
         let workers = (0..n_worker_threads)
             .map(|id| {
                 let arg = TaskWorkerThreadArg::new(
                     TaskWorkerId::new(id as u16),
-                    task_executor_lock.clone(),
+                    locks.task_executor_lock.clone(),
                     repos.clone(),
                 );
-                GenericWorker::new(event_queue.clone(), worker_stop_coordinate.clone(), arg)
+                GenericWorker::new(
+                    locks.main_job_lock.clone(),
+                    event_queues.clone(),
+                    coordinators.clone(),
+                    arg,
+                )
             })
             .collect();
         Self {
